TraceManager

Struct TraceManager 

pub struct TraceManager { /* private fields */ }
Manages in-flight trace fetch requests using promises.

Similar to QueryManager for metrics, but for trace operations.

Implementations

Source

impl TraceManager

pub fn new() -> Self

Create a new trace manager.

pub fn is_fetching_trace(&self) -> bool

Check if a trace fetch is in flight.

pub fn is_searching(&self) -> bool

Check if a search is in flight.

pub fn fetch_trace<C: TracingClient + ?Sized>( &mut self, client: &C, trace_id: &str, ctx: &Context, )

Fetch a trace by ID.

If a fetch is already in flight, it is cancelled and replaced.

pub fn search<C: TracingClient + ?Sized>( &mut self, client: &C, params: TraceSearchParams, ctx: &Context, )

Search for traces.

If a search is already in flight, it is cancelled and replaced.

pub fn poll_trace(&mut self) -> Option<TraceResult>

Poll for trace fetch result.

Returns Some(result) if a fetch just completed, None otherwise.

Poll for search result.

Returns Some(result) if a search just completed, None otherwise.

pub fn cancel_trace(&mut self)

Cancel any pending trace fetch.

Cancel any pending search.

pub fn cancel_all(&mut self)

Cancel all pending operations.