pub struct TraceManager { /* private fields */ }Expand description
Manages in-flight trace fetch requests using promises.
Similar to QueryManager for metrics, but for trace operations.
Implementations
Sourceimpl TraceManager
impl TraceManager
Sourcepub fn is_fetching_trace(&self) -> bool
pub fn is_fetching_trace(&self) -> bool
Check if a trace fetch is in flight.
Sourcepub fn is_searching(&self) -> bool
pub fn is_searching(&self) -> bool
Check if a search is in flight.
Sourcepub fn fetch_trace<C: TracingClient + ?Sized>(
&mut self,
client: &C,
trace_id: &str,
ctx: &Context,
)
pub fn fetch_trace<C: TracingClient + ?Sized>( &mut self, client: &C, trace_id: &str, ctx: &Context, )
Fetch a trace by ID.
If a fetch is already in flight, it is cancelled and replaced.
Sourcepub fn search<C: TracingClient + ?Sized>(
&mut self,
client: &C,
params: TraceSearchParams,
ctx: &Context,
)
pub fn search<C: TracingClient + ?Sized>( &mut self, client: &C, params: TraceSearchParams, ctx: &Context, )
Search for traces.
If a search is already in flight, it is cancelled and replaced.
Sourcepub fn poll_trace(&mut self) -> Option<TraceResult>
pub fn poll_trace(&mut self) -> Option<TraceResult>
Poll for trace fetch result.
Returns Some(result) if a fetch just completed, None otherwise.
Sourcepub fn poll_search(&mut self) -> Option<SearchResult>
pub fn poll_search(&mut self) -> Option<SearchResult>
Poll for search result.
Returns Some(result) if a search just completed, None otherwise.
Sourcepub fn cancel_trace(&mut self)
pub fn cancel_trace(&mut self)
Cancel any pending trace fetch.
Sourcepub fn cancel_search(&mut self)
pub fn cancel_search(&mut self)
Cancel any pending search.
Sourcepub fn cancel_all(&mut self)
pub fn cancel_all(&mut self)
Cancel all pending operations.